"""
Filename: ATMLite.py
Author: Mark Clarkson
Date: July, 2012
Description: A simple ATM simulator
"""

#simple procedure to force-quit the program from any point without
#following returns back through the other functions
def returnCard():
    print("Returning card now, thank you for your custom")
    global keepGoing #see note at bottom of program on global variables
    keepGoing = False


#simple procedure to display the current and available balance
def displayBalance(balance):
    #cleanup balance for stray 1/10ths of pennies, etc.
    balance = int(balance * 100)
    balance = balance / 100
    maxAvail = (balance // 10) * 10
    print("Current balance, £",balance)
    print("Maximum withdrawal, £",maxAvail)


#subtract a set amount form the balance (checking money available)
#prompt for an 'other' figure, if needed & check it is a multiple of £10
def subtract(balance,amount = 1): #if amount is not passed, set it to 1

    while amount % 10 != 0: #while amount not a multiple of 10
        amount = int(input("Enter an amount to withdraw (multiple of £10): "))
        if amount % 10 != 0:
            print("Error, invalid amount. Try again or enter '0' to return")
            # if user enters 0 then mod operation is satisfied and code below will run,
            # making no change to the balance

    #Check if there is enough in the account
    if balance > amount:
        balance = balance - amount
        print("£",amount,"withdrawn. Please collect your money")
    else:
        print("Sorry, insufficient funds available")

    return balance


#display withdrawal menu and handle choice
def withdraw(balance):
    menu = "Enter amount to withdraw.\n\
1 - £10\n\
2 - £20\n\
3 - £40\n\
4 - £60\n\
5 - £80\n\
6 - £100\n\
7 - Other Amount\n\
8 - Return to Main Menu\n\
9 - Return Card\n"

    option = 0

    while option < 1 or option > 9:
        option = int(input(menu))
        if option == 1:
            balance = subtract(balance,10)
            return balance
        elif option == 2:
            balance = subtract(balance,20)
            return balance
        elif option == 3:
            balance = subtract(balance,40)
            return balance
        elif option == 4:
            balance = subtract(balance,60)
            return balance
        elif option == 5:
            balance = subtract(balance,80)
            return balance
        elif option == 6:
            balance = subtract(balance,100)
            return balance
        elif option == 7:
            balance = subtract(balance)
            return balance
        elif option == 8:
            break
        elif option == 9:
            returnCard()
            return balance


#Handle deposits by asking for an amount.
#0 amount will have no effect (will look like returning to main menu)
#999 will quit (you can't deposit £999, sorry
#Note loack of validation. Negative numbers will work
def deposit(balance):
    menu = "Enter the deposit amount. \n\
Enter 0 to return to main menu.\n\
Enter 999 to return card\n"

    choice = float(input(menu))

    if choice == 999:
        returnCard()
    else:
       balance = balance + choice

    return balance


#Display main menu, get choice, run appropriate function
def mainMenu(balance):
    menu = "\n\n\n==============================\n\
Welcome to Northern Frock\n\
1 - Display Balance\n\
2 - Withdraw Funds\n\
3 - Deposit Funds\n\
9 - Return Card\n\
Enter an option: "

    invalidChoice = True #Assume invalid and repeat until valid choice
    
    while invalidChoice:
        choice = int(input(menu))
        if choice == 1:
            invalidChoice = False
            displayBalance(balance)
        elif choice == 2:
            invalidChoice = False
            balance = withdraw(balance)
        elif choice == 3:
            invalidChoice = False
            balance = deposit(balance)
        elif choice == 9:
            returnCard()
        else:
            print("\n\nInvalid choice, please try again.")

        return balance


#Main Method
balance = 67.14
keepGoing = True
while keepGoing:
    balance = mainMenu(balance)

"""
Some notes on global variables:

You will notice that the balance vairable is constantly being passed to functions
and returned back. This means that balance is always a local variable (i.e. it
exists within that function). This also means that any changes don't affect the
rest of the program until the variable is returned (so we can try doing things
in a non-destructive manner).

You will also notice that the keepGoing variable is not passed, but in the
returnCard() method there are two lines referring to it. The first declares
keepGoing as a global variable (otherwise Python will assume it is a local variable
and make a new one that only exists within that method). The second assigns a new
value so that the global variable will be updated immediately without the need to
pass th evariable around from one method to another.

Global variables are generally frowned upon for many reasons, but in this case it is
simpler to refer to keepGoing without having to pass it to methods that will never
need to use it. This isn;t the case with the balance variable which is used by several
of the functions in the code above.
"""

            
